#! /usr/bin/env lua

local lfs = require('lfs')

local function calc_std(tbl)
    if #tbl == 1 then return tbl[1], 0 end

    local total = 0
    
    for i, j in ipairs(tbl) do
        total = total + j
    end
    
    local mean = total / #tbl
    local sum  = 0
    
    for i, j in ipairs(tbl) do
        local tmp = mean - j
        sum = sum + tmp * tmp
    end
    
    local std = math.sqrt(sum / (#tbl - 1) )
    return mean, std
end

local sf = string.format
local ex = os.execute
local ti = table.insert

local function test()
    ex('./train > /dev/null')
    local f = io.popen('./test s')
    local n = f:read('*n')
    
    local sample, error = {}, {}
    
    for i = 1, n do
        local s = f:read('*n')
        local e = f:read('*n')
        ti(sample, s)
        ti(error,  e)
    end
    
    sample.mean = f:read('*n')
    
    f:close()
    return sample, error
end

local function merge_sep(dest, src)
    for i = 1, #src do
        if not dest[i] then dest[i] = {} end
        ti(dest[i], src[i])
    end
end

local function merge_all(dest, src)
    for i = 1, #src do
        ti(dest, src[i])
    end
end

local dir = assert( arg[1] )
lfs.chdir(dir)

local N = 10000

local sep, all = {}, {}
local s

for t = 1, N do
    print(t, N)
    local e
    s, e = test()
    merge_sep(sep, e)
    merge_all(all, e)
end

-- all
local mean, std = calc_std(all)
print( sf('* All *\nmean: %.4f | std: %.4f', mean, std) )

-- per sample
print('* Per sample *')
for i = 1, #s do
    local mean, std = calc_std( sep[i] )
    print( sf('sample: %.2f | mean: %.4f | std: %.4f', s[i], mean, std) )
end
