#include <supernn>
#include <cstdio>

using namespace SuperNN;

int main(int argc, char* argv[])
{
    Data test;
    test.load_file("test.data");
    Runner r("impedance.net", "impedance.info");
    
    double err_acc = 0;
    bool silent = argc == 2 && argv[1][0] == 's';
    
    if(silent) printf("%d\n", test.size());
    
    for(unsigned i = 0, e = test.size(); i < e; ++i)
    {
        r.inp(0) = test[i][0];
        r.inp(1) = test[i][1];
        r.run();
        
        double err = fabs(test[i][2] - r.out(0));
        err_acc += err;
        
        if(silent)
            printf("%.2lf %.12lf\n", test[i][2], err);
        else
            printf("Actual: %.2lf%% | Estimated: %.2lf%%\n", test[i][2], r.out(0));
        
    }
    
    double mean = err_acc / test.size();
    
    if(silent)
        printf("%.12lf\n", mean);
    else
        printf("Mean absolute error: %.2lf%%\n", mean);
    
    return 0;
}
