/**
 * Uses supernn: http://oproj.tuxfamily.org/wiki/doku.php?id=supernn
 */

#include <supernn>
#include <cstdio>

using namespace SuperNN;

int main(int argc, char* argv[])
{
    Utils::rand_seed();
    
    Network net = Network::make_fcc(1, 2, 1);
    net.set_activation(ACT_SIGMOID_SYMMETRIC, 0.5);
    
    // load both data sets to properly compute the data bounds
    Data train_data, test_data;
    train_data.load_file("train.data");
    test_data.load_file("test.data");
    
    Bounds& btrain = train_data.calc_bounds();
    Bounds& btest  = test_data.calc_bounds();
    btrain.merge_with(btest);
    train_data.scale(-1, 1);
    
    // from now on test_data is ignored
    NBN t;
    t.prepare(net);
    net.init_weights(-0.2, -0.1);
    unsigned e = t.train(net, train_data, 1e-3, 50);
    printf("Iterations     : %d\n" ,    e);
    printf("MSE            : %lf\n",    net.calc_mse(train_data));
    printf("Classification : %lf%%\n",  net.calc_class(train_data, 0.1));
    
    net.save_file("refractive.net");
    train_data.save_info_file("refractive.info");
    
    return 0;
}
